# S3P-SDK

## Быстрый старт

```shell
pip install s3p-sdk
```

## Оглавление
1. [Конфигурация](docs/config.md)
2. [Логика](docs/payload.md)
3. [Сборшик](docs/source-plugin)

## Пакет
Официально пакет представлен в [пакетном репозитории python](https://pypi.org/project/s3p-sdk/)